@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Glorified metronome
 
-our $VERSION = '0.6008';
+our $VERSION = '0.6009';
 
 use 5.024;
 use strictures 2;
@@ -246,13 +246,13 @@ sub set_volume ( $self, $volume = 0 ) {
 #pod
 #pod   $d->set_bpm($bpm);
 #pod
-#pod Reset the L<beats per minute|MIDI::Drummer::Tiny::Types/BPM>.
+#pod Return or set the beats per minute.
 #pod
 #pod =cut
 
 has bpm => (
     is      => 'rw',
-    isa     => BPM,
+    isa     => PosInt,
     default => 120,
     writer  => 'set_bpm',
     trigger => 1,
@@ -1467,7 +1467,7 @@ MIDI::Drummer::Tiny - Glorified metronome
 
 =head1 VERSION
 
-version 0.6008
+version 0.6009
 
 =head1 SYNOPSIS
 
@@ -1653,7 +1653,7 @@ If not given a B<volume> argument, this method mutes (sets to C<0>).
 
   $d->set_bpm($bpm);
 
-Reset the L<beats per minute|MIDI::Drummer::Tiny::Types/BPM>.
+Return or set the beats per minute.
 
 =head2 new
 
